[Bf-blender-cvs] [c62ebef] master: Usual i18n messages fixes. Also had to update i18n scripts to new BLT module...

Bastien Montagne noreply at git.blender.org
Tue Aug 25 21:13:49 CEST 2015


Commit: c62ebefcfcabde0d3df98e65cf8c05e8319cc387
Author: Bastien Montagne
Date:   Tue Aug 25 21:12:36 2015 +0200
Branches: master
https://developer.blender.org/rBc62ebefcfcabde0d3df98e65cf8c05e8319cc387

Usual i18n messages fixes. Also had to update i18n scripts to new BLT module...

===================================================================

M	release/scripts/modules/bl_i18n_utils/settings.py
M	release/scripts/modules/bl_i18n_utils/utils_spell_check.py
M	source/blender/makesrna/intern/rna_space.c

===================================================================

diff --git a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
index e2f2aee..b1aa4e0 100644
--- a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
+++ b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
@@ -97,6 +97,7 @@ class SpellChecker:
         "denoise",
         "deselect", "deselecting", "deselection",
         "despill", "despilling",
+        "dirtree",
         "editcurve",
         "editmesh",
         "filebrowser",
@@ -113,7 +114,7 @@ class SpellChecker:
         "libdata",
         "lightless",
         "lineset",
-        "linestyle",
+        "linestyle", "linestyles",
         "localview",
         "lookup", "lookups",
         "mathutils",
@@ -128,6 +129,7 @@ class SpellChecker:
         "multiuser",
         "multiview",
         "namespace",
+        "nodetree", "nodetrees",
         "keyconfig",
         "online",
         "playhead",
diff --git a/source/blender/makesrna/intern/rna_space.c b/source/blender/makesrna/intern/rna_space.c
index cc92f7c..186efff 100644
--- a/source/blender/makesrna/intern/rna_space.c
+++ b/source/blender/makesrna/intern/rna_space.c
@@ -3763,7 +3763,7 @@ static void rna_def_fileselect_params(BlenderRNA *brna)
 		               "Freestyle Linestyles", "Show/hide Freestyle's Line Style datablocks"},
 		{FILTER_ID_LT, "LATTICE", ICON_LATTICE_DATA, "Lattices", "Show/hide Lattice datablocks"},
 		{FILTER_ID_MA, "MATERIAL", ICON_MATERIAL_DATA, "Materials", "Show/hide Material datablocks"},
-		{FILTER_ID_MB, "METABALL", ICON_META_DATA, "Metaballs", "Show/hide Mateball datablocks"},
+		{FILTER_ID_MB, "METABALL", ICON_META_DATA, "Metaballs", "Show/hide Metaball datablocks"},
 		{FILTER_ID_MC, "MOVIE_CLIP", ICON_CLIP, "Movie Clips", "Show/hide Movie Clip datablocks"},
 		{FILTER_ID_ME, "MESH", ICON_MESH_DATA, "Meshes", "Show/hide Mesh datablocks"},
 		{FILTER_ID_MSK, "MASK", ICON_MOD_MASK, "Masks", "Show/hide Mask datablocks"},




More information about the Bf-blender-cvs mailing list
diff --git a/release/scripts/modules/bl_i18n_utils/settings.py b/release/scripts/modules/bl_i18n_utils/settings.py
index a63633d..49dbfbe 100644
--- a/release/scripts/modules/bl_i18n_utils/settings.py
+++ b/release/scripts/modules/bl_i18n_utils/settings.py
@@ -184,15 +184,15 @@ DOMAIN = "blender"
 # File type (ext) to parse.
 PYGETTEXT_ALLOWED_EXTS = {".c", ".cpp", ".cxx", ".hpp", ".hxx", ".h"}
 
 # Max number of contexts into a BLF_I18N_MSGID_MULTI_CTXT macro...
 PYGETTEXT_MAX_MULTI_CTXT = 16
 
 # Where to search contexts definitions, relative to SOURCE_DIR (defined below).
-PYGETTEXT_CONTEXTS_DEFSRC = os.path.join("source", "blender", "blenfont", "BLF_translation.h")
+PYGETTEXT_CONTEXTS_DEFSRC = os.path.join("source", "blender", "blentranslation", "BLT_translation.h")
 
 # Regex to extract contexts defined in BLF_translation.h
 # XXX Not full-proof, but should be enough here!
-PYGETTEXT_CONTEXTS = "#define\\s+(BLF_I18NCONTEXT_[A-Z_0-9]+)\\s+\"([^\"]*)\""
+PYGETTEXT_CONTEXTS = "#define\\s+(BLT_I18NCONTEXT_[A-Z_0-9]+)\\s+\"([^\"]*)\""
 
 # Keywords' regex.
 # XXX Most unfortunately, we can't use named backreferences inside character sets,
@@ -255,7 +255,7 @@ PYGETTEXT_KEYWORDS = (() +
 
     tuple((r"{}\(\s*" + _msg_re + r"\s*,\s*(?:" +
            r"\s*,\s*)?(?:".join(_ctxt_re_gen(i) for i in range(PYGETTEXT_MAX_MULTI_CTXT)) + r")?\s*\)").format(it)
-          for it in ("BLF_I18N_MSGID_MULTI_CTXT",))
+          for it in ("BLT_I18N_MSGID_MULTI_CTXT",))
 )
 
 # Check printf mismatches between msgid and msgstr.
@@ -333,6 +333,7 @@ WARN_MSGID_NOT_CAPITALIZED_ALLOWED = {
     "expected a view3d region & editcurve",
     "expected a view3d region & editmesh",
     "image file not found",
+    "image format is read-only",
     "image path can't be written to",
     "in memory to enable editing!",
     "jumps over",
@@ -184,15 +184,15 @@ DOMAIN = "blender"
 PYGETTEXT_ALLOWED_EXTS = {".c", ".cpp", ".cxx", ".hpp", ".hxx", ".h"}
 
-# Max number of contexts into a BLF_I18N_MSGID_MULTI_CTXT macro...
+# Max number of contexts into a BLT_I18N_MSGID_MULTI_CTXT macro...
 PYGETTEXT_MAX_MULTI_CTXT = 16
 
@@ -184,15 +184,15 @@ DOMAIN = "blender"
 
-# Regex to extract contexts defined in BLF_translation.h
+# Regex to extract contexts defined in BLT_translation.h
 # XXX Not full-proof, but should be enough here!